// Generated by CoffeeScript 1.7.1
var ControlBase, Password, Textbox, async, exports, extend, _,
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

_ = require('underscore');

async = require('async');

extend = require('extend');

ControlBase = (function() {
  function ControlBase(attrs) {
    var attr, attrList, _i, _len;
    if (Array.isArray(attrs)) {
      attrList = attrs;
      attrs = {};
      for (_i = 0, _len = attrList.length; _i < _len; _i++) {
        attr = attrList[_i];
        attrs[attr.name] = attr;
      }
    }
    this.attrs = attrs;
  }

  ControlBase.prototype.makeAttrs = function(element, options, next) {
    var attr, attrs, k, newOptions;
    attrs = (function() {
      var _ref, _results;
      _ref = this.attrs;
      _results = [];
      for (k in _ref) {
        attr = _ref[k];
        if (attr.makeAttr != null) {
          _results.push(attr);
        }
      }
      return _results;
    }).call(this);
    newOptions = extend({
      element: element
    }, options);
    return async.eachSeries(attrs, (function(x, cb) {
      return x.makeAttr(newOptions, cb);
    }), function(err) {
      if (err != null) {
        return next(err);
      }
      return next(null, element);
    });
  };

  ControlBase.prototype.verifyAttrs = function(value, options, next) {
    var attr, attrs, k, newOptions;
    attrs = (function() {
      var _ref, _results;
      _ref = this.attrs;
      _results = [];
      for (k in _ref) {
        attr = _ref[k];
        if (attr.verify != null) {
          _results.push(attr);
        }
      }
      return _results;
    }).call(this);
    newOptions = extend({
      value: value
    }, options);
    return async.eachSeries(attrs, (function(x, cb) {
      return x.verify(newOptions, cb);
    }), function(err) {
      if (err != null) {
        return next(err);
      }
      return next(null, value);
    });
  };

  return ControlBase;

})();

Textbox = (function(_super) {
  __extends(Textbox, _super);

  function Textbox(attrs) {
    Textbox.__super__.constructor.call(this, attrs);
  }

  Textbox.prototype.make = function(options, next) {
    var body, element, fieldName, req, value;
    req = options.req, fieldName = options.fieldName;
    element = {
      name: fieldName,
      tag: "input",
      type: "text"
    };
    body = req.body || {};
    value = body[fieldName];
    element["value"] = value || '';
    return this.makeAttrs(element, options, next);
  };

  Textbox.prototype.val = function(options, next) {
    var body, fieldName, req, value;
    req = options.req, fieldName = options.fieldName;
    body = req.body || {};
    value = body[fieldName];
    return this.verifyAttrs(value, options, next);
  };

  return Textbox;

})(ControlBase);

Password = (function(_super) {
  __extends(Password, _super);

  function Password(attrs) {
    Password.__super__.constructor.call(this, attrs);
  }

  Password.prototype.make = function(options, next) {
    var body, element, fieldName, req, value;
    req = options.req, fieldName = options.fieldName;
    element = {
      name: fieldName,
      tag: "input",
      type: "password"
    };
    body = req.body || {};
    value = body[fieldName];
    element["value"] = value || '';
    return this.makeAttrs(element, options, next);
  };

  Password.prototype.val = function(options, next) {
    var body, fieldName, req, value;
    req = options.req, fieldName = options.fieldName;
    body = req.body || {};
    value = body[fieldName];
    return this.verifyAttrs(value, options, next);
  };

  return Password;

})(ControlBase);

exports = module.exports = {
  textbox: function(attrs) {
    if (attrs == null) {
      attrs = {};
    }
    return new Textbox(attrs);
  },
  password: function(attrs) {
    if (attrs == null) {
      attrs = [];
    }
    return new Password(attrs);
  },
  attrs: {
    maxlength: function(len, error) {
      return {
        makeAttr: function(options, next) {
          var element, fieldName;
          fieldName = options.fieldName, element = options.element;
          element['maxlength'] = len;
          return next(null);
        },
        verify: function(options, next) {
          var res, t, value;
          value = options.value, res = options.res;
          if ((value != null) && value.length > len) {
            t = res.locals.$i18n.t;
            return next(t(error));
          }
          return next(null);
        },
        name: 'maxlength'
      };
    },
    required: function(error) {
      return {
        makeAttr: function(options, next) {
          var element;
          element = options.element;
          element['required'] = true;
          return next(null);
        },
        verify: function(options, next) {
          var res, t, value;
          value = options.value, res = options.res;
          t = res.locals.$i18n.t;
          if (!value) {
            return next(t(error));
          }
          return next(null);
        },
        name: 'required'
      };
    },
    placeholder: function(text) {
      return {
        makeAttr: function(options, next) {
          var element, fieldName, req, res;
          fieldName = options.fieldName, element = options.element, req = options.req, res = options.res;
          if (res.locals.$i18n != null) {
            text = res.locals.$i18n.t(text);
          }
          element['placeholder'] = text;
          return next(null);
        },
        name: 'placeholder'
      };
    },
    text: function(text) {
      return {
        makeAttr: function(options, next) {
          var element, fieldName, res;
          fieldName = options.fieldName, element = options.element, res = options.res;
          element['text'] = res.locals.$i18n.t(text);
          return next(null);
        },
        name: 'text'
      };
    },
    verify: function(fn, error) {
      return {
        verify: function(options, next) {
          var fieldName, req, res, t, value;
          fieldName = options.fieldName, value = options.value, req = options.req, res = options.res;
          t = res.locals.$i18n.t;
          return fn(options, function(err, result) {
            if (err != null) {
              return next(err);
            }
            if (!result) {
              return next(t(error));
            }
            return next(null);
          });
        },
        name: 'verify'
      };
    }
  }
};

//# sourceMappingURL=editor.map
